@@ -15,6 +15,9 @@
  * limitations under the License.
  */
 
+// Make sure that the tests are being executed from the current working dir
+chdir(__DIR__);
+
 require_once '../src/Google_Client.php';
 class BaseTest extends PHPUnit_Framework_TestCase {
   /**
@@ -26,10 +29,13 @@ class BaseTest extends PHPUnit_Framework_TestCase {
     if (!BaseTest::$client) {
       global $apiConfig;
       $apiConfig['ioFileCache_directory'] = '/tmp/google-api-php-client/tests';
+      $apiConfig['cacheClass'] = 'Google_FileCache';
 
       BaseTest::$client = new Google_Client();
       if (!BaseTest::$client->getAccessToken()) {
-        BaseTest::$client->setAccessToken($apiConfig['oauth_test_token']);
+        if (isset($apiConfig['oauth_test_token'])) {
+          BaseTest::$client->setAccessToken($apiConfig['oauth_test_token']);
+        }
       }
     }
   }
@@ -38,4 +44,4 @@ class BaseTest extends PHPUnit_Framework_TestCase {
     global $apiConfig;
     $apiConfig['oauth_test_token'] = self::$client->getAccessToken();
   }
-}
\ No newline at end of file
+}
